"use client";
import { cn } from "@/lib/utils";
import { usePaginatedProducts } from "@/servers/data/use-product";
import { Loader2 } from "lucide-react";
import { useTranslations } from "next-intl";
import { useMemo, useState } from "react";
import HeaderFilters from "./_components/header-filters";
import ProductCard from "./_components/product-card";
import ProductPagination from "./_components/product-pagination";
import SidebarFilters, { ProductFilters } from "./_components/sidebar-filters";


// --- Constants ---
const ITEMS_PER_PAGE = 10; // Number of products per page

// Define product type
interface Product {
	id: number;
	name: string;
	product_slug: string;
	price: number;
	oldPrice: number | null;
	imageUrl: string;
}

export default function Products({ min, max }: any) {
	const t = useTranslations();

	const [viewMode, setViewMode] = useState("grid");
	const [activeSort, setActiveSort] = useState("Best sellers");
	const [priceSortDirection, setPriceSortDirection] = useState<"asc" | "desc">("asc");
	const [currentPage, setCurrentPage] = useState(1); // State for current page
	const [filters, setFilters] = useState<ProductFilters>({
		category_id: undefined,
		group_id: undefined,
		min_price: min,
		max_price: max,
		brand_id: undefined,
	});
	const [nameFilter, setNameFilter] = useState("");


	// Function to toggle price sort direction
	const togglePriceSort = () => {
		setPriceSortDirection(prev => prev === "asc" ? "desc" : "asc");
		setCurrentPage(1); // Reset to first page on sort change
	};

	// Determine sort parameters based on activeSort
	const sortParams = useMemo(() => {
		switch (activeSort) {
			case "Price":
				return {
					order_by_price: priceSortDirection === "asc" ? true : false
				};
			case "Best sellers":
				return {
					order_by_most_selling: true
				};
			case "Newest":
				return {
					order_by_newest: true
				};
			case "Best rated":
				return {
					order_by_rating: true
				};
			default:
				return {};
		}
	}, [activeSort, priceSortDirection]);

	// Use the paginated products hook with the currentPage directly
	const {
		products,
		totalPages,
		isLoading: isProductsLoading,
		isError,
		refetch,
	} = usePaginatedProducts(
		currentPage,
		ITEMS_PER_PAGE,
		{
			...filters,
			...sortParams,
			name: nameFilter || ""
		}
	);



	// Handle page change
	const handlePageChange = (page: number) => {
		console.log("page: ", page);
		if (page >= 1 && page <= totalPages) {
			setCurrentPage(page);

			// Scroll to the top of the page
			window.scrollTo({
				top: 0,
				behavior: "smooth"
			});
		}
	};

	// Handle filter changes
	const handleFilterChange = (newFilters: ProductFilters) => {
		console.log("newFilters: ", newFilters);

		// Check if filters have actually changed
		const hasFiltersChanged =
			newFilters.category_id !== filters.category_id ||
			newFilters.group_id !== filters.group_id ||
			newFilters.min_price !== filters.min_price ||
			newFilters.max_price !== filters.max_price ||
			newFilters.brand_id !== filters.brand_id;

		setFilters(newFilters);

		// Only reset to page 1 if filters have actually changed
		if (hasFiltersChanged) {
			setCurrentPage(1); // Reset to first page when filters change
		}
	};

	// Handle name filter changes
	const handleNameFilterChange = (name: string) => {
		// Only reset to page 1 if the name filter is actually changing
		if (name !== nameFilter) {
			setNameFilter(name);
			setCurrentPage(1); // Reset to first page when name filter changes
		}
	};


	return (
		<div dir="ltr" className="min-h-screen bg-gray-50 font-sans p-4 md:p-8 lg:p-16">
			<div className="container mx-auto px-4 py-6">

				<HeaderFilters
					viewMode={viewMode}
					setViewMode={setViewMode}
					activeSort={activeSort}
					setActiveSort={(sort: string) => { setActiveSort(sort); setCurrentPage(1); }}
					priceSortDirection={priceSortDirection}
					togglePriceSort={togglePriceSort}
					onNameFilterChange={handleNameFilterChange}
				/>

				<div className="flex flex-col lg:flex-row gap-6">
					<div className="w-full lg:w-auto">
						<SidebarFilters
							min_price={min}
							max_price={max}
							onFilterChange={handleFilterChange}
						/>
					</div>

					<main className="flex-1">
						{isProductsLoading ? (
							<div className="flex justify-center items-center h-64">
								<Loader2 className="w-10 h-10 mx-auto animate-spin" />
							</div>
						) : isError ? (
							<div className="flex justify-center items-center h-64">
								<p>{t("Error loading products, Please try again")}</p>
							</div>
						) : products?.length > 0 ? (
							<>
								{/* Product Grid */}
								<div className={cn(`grid gap-6 ${viewMode === "grid"
									? "grid-cols-1 sm:grid-cols-2 md:grid-cols-2 lg:grid-cols-3 xl:grid-cols-3"
									: "grid-cols-1"
									}`)}>
									{products?.map((product: Product) => (
										<ProductCard key={product.id} product={product} refetch={refetch} />
									))}
								</div>

								{/* Pagination Controls */}
								{totalPages > 1 && (
									<ProductPagination
										key={`pagination-${currentPage}`}
										currentPage={currentPage}
										totalPages={totalPages}
										handlePageChange={handlePageChange}
									/>
								)}
							</>
						) : (
							<div className="flex justify-center items-center h-64">
								<p>{t("No products found")}</p>
							</div>
						)}
					</main>
				</div>
			</div>
		</div>
	);
}



